@@ -2,6 +2,8 @@ import sys, base64, os, datetime
 from dateutil import parser
 from ddd_objects.domain.value_obj import ExpiredValueObject, ValueObject
 from ddd_objects.domain.exception import FormatError, ValueError, ParameterError
+from vpc_control_ao.domain.value_obj import CommandID, CommandPriority
+from vpc_control_ao.domain.value_obj_ext import PipelineContext
 python_version_minor = sys.version_info.minor
 
 class Number(ExpiredValueObject):
@@ -230,9 +232,12 @@ class InstanceStatus(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
-class Time(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
+class K3SRunTime(ValueObject):
+    def __init__(self, value) -> None:
+        if isinstance(value, datetime.timedelta):
+            self.value = value.total_seconds()
+        else:
+            self.value = float(value)
 
 class Version(ExpiredValueObject):
     def __init__(self, value):
