@@ -64,6 +64,13 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeInfoDO(**info) for info in infos]
 
+    def clear_node(self, node_name: str, timeout=60):
+        response=requests.delete(f'{self.url}/node/node_name/{node_name}', 
+                    headers=self.header, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
     def delete_nodes(self, node_infos: List[ReleaseNodeInfoDO], timeout=60):
         data = [info.dict() for info in node_infos]
         data = json.dumps(data)
